<?php

namespace Drupal\dmg;

use Drupal\Component\Utility\Xss;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\field_ui\EntityDisplayModeListBuilder as CoreEntityDisplayModeListBuilder;
use Symfony\Component\HttpFoundation\RedirectResponse;

class EntityDisplayModeListBuilder extends CoreEntityDisplayModeListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $headers = parent::buildHeader();
    $operations = array_pop($headers);
    $headers[] = $this->t('Guidelines');
    $headers[] = $operations;
    return $headers;
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row = parent::buildRow($entity);
    $operations = array_pop($row);
    $guidelines = $entity->getThirdPartySetting('dmg', 'guidelines', $this->t('<em>- No guidelines configured yet -</em>'));
    $row[]['data'] = ['#markup' => Xss::filterAdmin($guidelines)];
    $row[] = $operations;
    return $row;
  }

  /**
   * {@inheritdoc}
   */
  public function render() {
    $build = parent::render();
    $entity_types = array_keys($this->load());
    $type = str_replace(['entity_', '_mode'], '', $this->entityTypeId);
    foreach ($entity_types as $entity_type) {
      $table = &$build[$entity_type];
      $table['#rows']['_configure_guidelines'][] = [
        'data' => [
          '#type' => 'link',
          '#url' => Url::fromRoute('dmg.settings', [
            'type' => $type,
            'entity_type_id' => $this->entityTypes[$entity_type]->id(),
          ]),
          '#title' => $this->t('Configure creation guidelines for @entity-type %label', [
            '@entity-type' => $this->entityTypes[$entity_type]->getLabel(),
            '%label' => $this->entityType->getSingularLabel(),
          ]),
        ],
        'colspan' => count($table['#header']),
      ];
    }
    return $build;
  }

  public static function displayModeSettingsSubmit(array &$form, FormStateInterface $form_state) {
    return RedirectResponse::create('/');
  }

}
